/*============================================================================
 * User definition of physical properties.
 *============================================================================*/

/* code_saturne version 7.0 */

/*
  This file is part of Code_Saturne, a general-purpose CFD tool.

  Copyright (C) 1998-2021 EDF S.A.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 2 of the License, or (at your option) any later
  version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  details.

  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
  Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

/*----------------------------------------------------------------------------*/

#include "cs_defs.h"

/*----------------------------------------------------------------------------
 * Standard C library headers
 *----------------------------------------------------------------------------*/

#include <assert.h>
#include <math.h>
#include <string.h>

#if defined(HAVE_MPI)
#include <mpi.h>
#endif

/*----------------------------------------------------------------------------
 * PLE library headers
 *----------------------------------------------------------------------------*/

#include <ple_coupling.h>

/*----------------------------------------------------------------------------
 * Local headers
 *----------------------------------------------------------------------------*/

#include "cs_headers.h"

/*----------------------------------------------------------------------------*/

BEGIN_C_DECLS

/*----------------------------------------------------------------------------*/
/*!
 * \file cs_user_physical_properties.c
 *
 * \brief User definition of physical properties.
 */
/*----------------------------------------------------------------------------*/

/*============================================================================
 * User function definitions
 *============================================================================*/

/*----------------------------------------------------------------------------*/
/*!
 * \brief Function called at each time step to define physical properties.
 *
 * \param[in, out]  domain   pointer to a cs_domain_t structure
 */
/*----------------------------------------------------------------------------*/

void
cs_user_physical_properties2(cs_domain_t   *domain, 
				cs_real_t t[])
{
  CS_NO_WARN_IF_UNUSED(domain);

  /* Check fields exists */
  if (CS_F_(lambda) == NULL)
    bft_error(__FILE__, __LINE__, 0,_("error lambda not variable\n"));
  if (CS_F_(rho) == NULL)
    bft_error(__FILE__, __LINE__, 0,_("error rho not variable\n"));
  if (CS_F_(cp) == NULL)
    bft_error(__FILE__, __LINE__, 0,_("error cp not variable\n"));

  cs_real_t *cpro_lambda = CS_F_(lambda)->val;
  cs_real_t *cpro_rho = CS_F_(rho)->val;
  cs_real_t *cpro_cp = CS_F_(cp)->val;
  cs_real_t *cpro_mu = CS_F_(mu)->val;
  cs_real_t *cpro_beta;
  
  cs_real_t vara=1000000; /* Rayleigh number */
  cs_real_t varb=1; /* Width between the plates */
  cs_real_t varc=10;  /* \Delta T= Th-Tc  */
  
  cs_real_t rho0= cpro_rho[0];/* 1.2039 */
  cs_real_t Cp0= cpro_cp[0]; /* 1004.84 */
  cs_real_t t0= 293.15; /* 293.15 */
  cs_real_t mu0= cpro_mu[0]; /* 1.83e-5 */
  cs_real_t gz= 9.81; 

  /* Impose thermal conductivity, density and specific heat for solid zones */
  {
    /* Volume zone "CM" must be defined in the GUI or in cs_user_zones.c */
    const cs_zone_t *z = cs_volume_zone_by_name("CM");

    for (cs_lnum_t i = 0; i < z->n_elts; i++) {
      cs_lnum_t cell_id = z->elt_ids[i];
            
      cpro_beta[cell_id] = cpro_lambda[cell_id]*mu0*vara/(pow(rho0,2)*Cp0*abs(gz)*varc*pow(varb,3));
      cpro_rho[cell_id] = rho0 - rho0*cpro_beta[cell_id]*(t[cell_id]-t0);

    }
  }
}

/*----------------------------------------------------------------------------*/

END_C_DECLS
